#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""Extract student assignments nested in module zip dumps.

:author: `David King <mailto:david.king@open.ac.uk>`_
:project: eSTEeM - Measuring Qualification Effects framework extended
:version: 1.0.0
:copyright: `2016-2018 The Open University <http://www.open.ac.uk>`_
:licence: `GPL v3 <http://www.gnu.org/licenses/>`_
"""


import glob
import os.path
import zipfile

from mqe_common import set_folder

from mqe_regexs import GET_MODULE_CODE, GET_PID, GET_PRESENTATION_CODE


def extract_all(source_file, output_folder='../assignments/'):
    """Unzip all files in supplied source_file to source_folder."""
    set_folder(output_folder)
    extract_assignments(source_file, output_folder)
    zip_files = glob.iglob(os.path.join(output_folder, '**/*.zip'),
                           recursive=True)
    for zip_file in zip_files:
        print('Extracting {}'.format(zip_file), flush=True)
        module = GET_MODULE_CODE(zip_file).group()
        presentation = GET_PRESENTATION_CODE(zip_file).group()
        pid = GET_PID(zip_file).group()
        if '_01-' in zip_file:
            assignment = 'TMA01'
        elif '_02-' in zip_file:
            assignment = 'TMA02'
        elif '_03-' in zip_file:
            assignment = 'TMA03'
        elif '_30-' in zip_file:
            assignment = 'EMA'
        extract_assignment_files(zip_file, os.path.join(output_folder,
                                                        module + '-' + presentation,
                                                        pid,
                                                        assignment))
    tidy_up(source_file, output_folder)


def extract_assignments(source_file, output_folder):
    """Extract contents of source_file to output_folder."""
    with zipfile.ZipFile(source_file) as source_zip:
        source_zip.extractall(path=output_folder)


def extract_assignment_files(zip_file, extract_folder):
    """Unzip all zipped files in supplied source_folder."""
    with zipfile.ZipFile(zip_file) as unzip_file:
        unzip_file.extractall(path=extract_folder)
    os.remove(zip_file)


def tidy_up(source_file, output_folder):
    """Delete extract_assignments folder."""
    _, tail = os.path.split(source_file)
    dir_name = os.path.join(output_folder, tail[:-4])
    os.rmdir(dir_name)


if __name__ == '__main__':
    extract_all('../zipped-assignments/M811 17K.zip')
    extract_all('../zipped-assignments/M816 16K.zip')
    extract_all('../zipped-assignments/M816 17K.zip')
