#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""Demo of doctest and simple asserts.

:author: `David King <mailto:david.king@open.ac.uk>`_
:project: eSTEeM - Measuring Qualification Effects framework
:copyright: `2016 The Open University <http://www.open.ac.uk>`_
:licence: `GPL v3 <http://www.gnu.org/licenses/>`_
"""


def is_current(post):
    """Return True if post is latest version of that post in the forum.

    >>> import xml.etree.ElementTree as ET

    >>> xml_current = '''<?xml version="1.0" encoding="UTF-8"?> \
    <post> \
    <oldversion>0</oldversion> \
    </post> \
    '''
    >>> test_current = ET.fromstring(xml_current)
    >>> is_current(test_current)
    True

    >>> xml_old = '''<?xml version="1.0" encoding="UTF-8"?> \
    <post> \
    <oldversion>1</oldversion> \
    </post> \
    '''
    >>> test_old = ET.fromstring(xml_old)

    >>> is_current(test_old)
    False

    """
    return True if post.find('oldversion').text == '0' else False


def test_is_current():
    """Return True if post is latest version of that post in the forum."""
    import xml.etree.ElementTree as ET

    xml_current = '''<?xml version="1.0" encoding="UTF-8"?>
    <post>
    <oldversion>0</oldversion>
    </post>
    '''
    test_current = ET.fromstring(xml_current)
    assert is_current(test_current) == True

    xml_old = '''<?xml version="1.0" encoding="UTF-8"?>
    <post>
    <oldversion>1</oldversion>
    </post>
    '''
    test_old = ET.fromstring(xml_old)
    assert is_current(test_old) == False


if __name__ == "__main__":
    import doctest
    doctest.testmod()
 
    test_is_current()
